--- u-boot-1.1.6/common/cmd_bootm.c	2006-11-02 09:15:01.000000000 -0500
+++ u-boot/common/cmd_bootm.c	2007-07-20 11:47:23.000000000 -0400
@@ -146,6 +146,10 @@
 #define CFG_BOOTM_LEN	0x800000	/* use 8MByte as default max gunzip size */
 #endif
 
+#ifdef CONFIG_IMAGE_VERIFY
+int image_verify (const image_header_t *hdr);
+#endif
+
 image_header_t header;
 
 ulong load_addr = CFG_LOAD_ADDR;		/* Default Load Address */
@@ -297,6 +301,14 @@
 	}
 	SHOW_BOOT_PROGRESS (6);
 
+#ifdef CONFIG_IMAGE_VERIFY
+	if (!image_verify(hdr)) {
+		printf ("Image did not verify\n");
+		SHOW_BOOT_PROGRESS (-6);
+		return 1;
+	}
+#endif
+
 	/*
 	 * We have reached the point of no return: we are going to
 	 * overwrite all exception vector code, so we cannot easily
--- u-boot-1.1.6/README	2006-11-02 09:15:01.000000000 -0500
+++ u-boot/README	2007-07-20 12:04:49.000000000 -0400
@@ -2269,6 +2269,25 @@
 		some other boot loader or by a debugger which
 		performs these intializations itself.
 
+- CONFIG_IMAGE_VERIFY
+
+		If this option is defined, bootm will callout to
+		image_verify() and only boot the image if it returns nonzero.
+		Image_verify() should be defined by the BSP in board/ to
+		do whatever it wants to validate the image is okay for the
+		board.  For example, it might want check something in the
+		hdr->ih_name string.
+
 
 Building the Software:
 ======================
